#include<cstdlib>
#include<cstdio>
#include<gsl/gsl_rng.h>

/**
 * Draws a random number bewtween \f$[0,1]\f$ via rand.
 *
 * @return The drawn random number.
 */
double randomNumber01()
{
	return (double) rand() / RAND_MAX; // *
}

/**
 * Draws a random number in \f$[0,1]\f$ via the gsl.
 *
 * @param r A pointer to the random number generator which is used.
 *
 * @return The drawn random number.
 */
double randomNumber01GSL(gsl_rng* r)
{
	return gsl_rng_uniform(r);
}

// enable doxygen processing for this header:
/** @file */

/** 
 * Main function for random number evaluation.
 * A first random number \f$x_1\f$ is drawn via rand. 
 * A second random number \f$x_2\f$ is drawn via gsl_rng_uniform.
 *
 * Furthermore, an array of 10 doubles is allocated. However, someone 
 * seems to have forgotten to free the allocated space again in the end...
 *
 * @param argc The number of arguments provided.
 * @param argv An array of arguments (argv[0] is the name of the
 * executable).
 *
 * @return If everything worked fine, 0 is returned.
 */
int main(int argc, char* argv[]) {


	gsl_rng* r;
	r = gsl_rng_alloc(gsl_rng_mt19937);

	printf( "%lf\n", randomNumber01());

	printf( "%lf\n", randomNumber01GSL(r));

	gsl_rng_free(r);


	//Allocate a temporary array:
	double* tmp = (double*)malloc(10*sizeof(double));
	//Free the temporary array space:
	//free(tmp);


	return 0;
}
